@@ -1,5 +1,7 @@
 import requests
 
+RUNTIME_ENV_ORDERS = ["BAP", "EDD", "AIDP", "LOCAL"]
+
 CONFIG = {
     "LOCAL": {
         "LOCAL": {
@@ -14,17 +16,22 @@ CONFIG = {
             "LUNAR_REC_URL": "https://rec.dev.apollo-lunar.com",
             "LUNAR_DATA_URL": "https://data.dev.apollo-lunar.com",
         },
-        "LUNAR": {
-            "TEST_URL": "https://2mqu0rhpsc-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://2mqu0rhpsc-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://qu8pnrfq8c-vpce-0ea0f0c470612df61.execute-api.ap-northeast-2.amazonaws.com",
+        "BAP": {
+            "TEST_URL": "http://rec.lunar.apollo",
+            "LUNAR_REC_URL": "http://rec.lunar.apollo",
+            "LUNAR_DATA_URL": "http://data.lunar.apollo",
         },
     },
     "STG": {
+        "AIDP": {
+            "TEST_URL": "http://10.40.84.123:50070",
+            "LUNAR_REC_URL": "https://rec.stg.bap.apollo-ai.io",
+            "LUNAR_DATA_URL": "https://data.stg.bap.apollo-ai.io",
+        },
         "EDD": {
             "TEST_URL": "http://150.6.13.63:8081",
-            "LUNAR_REC_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://cp71v3ev9g-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://rec.stg.bap.apollo-ai.io",
+            "LUNAR_DATA_URL": "https://data.stg.bap.apollo-ai.io",
             "COPY_DATABASE_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_database",
             "COPY_FILES_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_files",
             "JOB_STATUS_URL": "http://150.6.13.9:31771/edd_to_lunar/job_status",
@@ -34,17 +41,22 @@ CONFIG = {
             "LUNAR_REC_URL": "https://rec.stg.apollo-lunar.com",
             "LUNAR_DATA_URL": "https://data.stg.apollo-lunar.com",
         },
-        "LUNAR": {
-            "TEST_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://gm05du691j-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://cp71v3ev9g-vpce-0fa38c61f2c3a311b.execute-api.ap-northeast-2.amazonaws.com",
+        "BAP": {
+            "TEST_URL": "http://rec.lunar.apollo",
+            "LUNAR_REC_URL": "http://rec.lunar.apollo",
+            "LUNAR_DATA_URL": "http://data.lunar.apollo",
         },
     },
     "PRD": {
+        "AIDP": {
+            "TEST_URL": "http://10.40.84.123:50070",
+            "LUNAR_REC_URL": "https://rec.bap.apollo-ai.io",
+            "LUNAR_DATA_URL": "https://data.bap.apollo-ai.io",
+        },
         "EDD": {
             "TEST_URL": "http://150.6.13.63:8081",
-            "LUNAR_REC_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://qrnczr2pc3-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
+            "LUNAR_REC_URL": "https://rec.bap.apollo-ai.io",
+            "LUNAR_DATA_URL": "https://data.bap.apollo-ai.io",
             "COPY_DATABASE_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_database",
             "COPY_FILES_URL": "http://150.6.13.9:31771/edd_to_lunar/copy_files",
             "JOB_STATUS_URL": "http://150.6.13.9:31771/edd_to_lunar/job_status",
@@ -54,37 +66,48 @@ CONFIG = {
             "LUNAR_REC_URL": "https://rec.apollo-lunar.com",
             "LUNAR_DATA_URL": "https://data.apollo-lunar.com",
         },
-        "LUNAR": {
-            "TEST_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_REC_URL": "https://6mxcp1mx6j-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
-            "LUNAR_DATA_URL": "https://qrnczr2pc3-vpce-0831759639ca45cb4.execute-api.ap-northeast-2.amazonaws.com",
+        "BAP": {
+            "TEST_URL": "http://rec.lunar.apollo",
+            "LUNAR_REC_URL": "http://rec.lunar.apollo",
+            "LUNAR_DATA_URL": "http://data.lunar.apollo",
         },
     },
 }
 
 
 class Config:
-    def __init__(self, env: str, apikey: str):
+    def __init__(self, env: str, apikey: str, runtime_env: str = None):
         assert env in CONFIG.keys(), f"`env` must be in {CONFIG.keys()}"
 
         setattr(self, "ENV", env)
         setattr(self, "APIKEY", apikey)
 
+        if runtime_env:
+            setattr(self, "RUNTIME_ENV", runtime_env)
+            try:
+                for key, url in CONFIG[env][runtime_env].items():
+                    setattr(self, key, url)
+            except KeyError:
+                raise Exception(f"BAP {env} does not support this {runtime_env} environment.")
+
+            return
+
         if env == "LOCAL":
             setattr(self, "RUNTIME_ENV", "LOCAL")
             for key, url in CONFIG[env]["LOCAL"].items():
                 setattr(self, key, url)
             return
 
-        for runtime_env, urls in CONFIG[env].items():
-            try:
-                requests.get(url=urls["TEST_URL"], timeout=0.1)
-                setattr(self, "RUNTIME_ENV", runtime_env)
-                for key, url in urls.items():
-                    setattr(self, key, url)
-                break
-            except Exception:
-                continue
+        for runtime_env_value in RUNTIME_ENV_ORDERS:
+            if urls := CONFIG[env].get(runtime_env_value):
+                try:
+                    requests.get(url=urls["TEST_URL"], timeout=0.5)
+                    setattr(self, "RUNTIME_ENV", runtime_env_value)
+                    for key, url in urls.items():
+                        setattr(self, key, url)
+                    break
+                except Exception:
+                    continue
 
         if not hasattr(self, "RUNTIME_ENV"):
-            raise Exception(f"Lunar {env} does not support this runtime environment.")
+            raise Exception(f"BAP {env} does not support this runtime environment.")
