@@ -7,31 +7,25 @@ from lunar.config import Config
 from lunar.lunar_client import LunarClient, LunarError
 from lunar.rec.experiments.models import Experiment, ExperimentPutIn, ExperimentPatchIn
 
-LUNAR_REC_EXPERIMENTS_API_URL = "/v1/experiments"
-
 loop = asyncio.get_event_loop()
 
 
 class ExperimentClient(LunarClient):
     """
-    Client for Lunar Recommendation API (`/v1/experiments/`).
+    Client for BAP Recommendation API (`/v1/experiments/`).
 
     ## Example
 
     ```python
-    import lunar
+    import bap
 
-    client = lunar.client("experiment")
+    client = bap.client("experiment")
     ```
     """
 
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = (
-            LUNAR_REC_EXPERIMENTS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_REC_EXPERIMENTS_API_URL}"
-        )
-
     async def create_experiment_async(
         self, id: str, buckets: List[Dict[str, Any]], bucketing_seed: str = ""
     ) -> Experiment:
@@ -69,7 +63,7 @@ class ExperimentClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="POST", url=self.api_url, data=experiment.dict())
+        body = await self._request(method="POST", url=self.config.API_PATH, data=experiment.dict())
         return Experiment(**body["data"])
 
     def create_experiment(self, id: str, buckets: List[Dict[str, any]], bucketing_seed: str = "") -> Experiment:
@@ -112,7 +106,7 @@ class ExperimentClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=self.api_url)
+        body = await self._request(method="GET", url=self.config.API_PATH)
         return [Experiment(**experiment) for experiment in body["data"]]
 
     def list_experiments(self) -> List[Experiment]:
@@ -149,7 +143,7 @@ class ExperimentClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=f"{self.api_url}/{id}")
+        body = await self._request(method="GET", url=f"{self.config.API_PATH}/{id}")
         return Experiment(**body["data"])
 
     def get_experiment(self, id: str) -> Experiment:
@@ -208,7 +202,7 @@ class ExperimentClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="PUT", url=f"{self.api_url}/{id}", data=updated_experiment.dict())
+        body = await self._request(method="PUT", url=f"{self.config.API_PATH}/{id}", data=updated_experiment.dict())
         return Experiment(**body["data"])
 
     def update_experiment(self, id: str, buckets: List[Dict[str, any]], bucketing_seed: str = "") -> Experiment:
@@ -269,7 +263,7 @@ class ExperimentClient(LunarClient):
         patched_experiment = ExperimentPatchIn(**{"buckets": buckets, "bucketing_seed": bucketing_seed})
 
         body = await self._request(
-            method="PATCH", url=f"{self.api_url}/{id}", data=patched_experiment.dict(exclude_none=True)
+            method="PATCH", url=f"{self.config.API_PATH}/{id}", data=patched_experiment.dict(exclude_none=True)
         )
         return Experiment(**body["data"])
 
@@ -318,7 +312,7 @@ class ExperimentClient(LunarClient):
         ```
         """
 
-        return await self._request(method="DELETE", url=f"{self.api_url}/{id}")
+        return await self._request(method="DELETE", url=f"{self.config.API_PATH}/{id}")
 
     def delete_experiment(self, id: str) -> None:
         """
